#
# spec file for package perl-Prima
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Prima
Version:        1.47
Release:        40.1
#Upstream: SUSE-Public-Domain
%define cpan_name Prima
Summary:        Perl Graphic Toolkit
License:        BSD-2-Clause
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Prima/
Source0:        http://www.cpan.org/authors/id/K/KA/KARASIK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
Patch0:         gcc-warnings.patch
Patch1:         Prima-GenericEvent.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  giflib-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  xkeyboard-config
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-Xvfb
BuildRequires:  xorg-x11-devel
%define         X_display         ":98"
Requires:       xorg-x11
# MANUAL END

%description
The toolkit is combined from two basic set of classes - core and external.
The core classes are coded in C and form a base line for every Prima object
written in perl. The usage of C is possible together with the toolkit;
however, its full power is revealed in the perl domain. The external
classes present easily expandable set of widgets, written completely in
perl and communicating with the system using Prima library calls.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644
%patch0 -p1
%patch1 

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
## oops, Prima/Config.pm must not contain BUILD_ROOT
find $RPM_BUILD_ROOT -name 'Config.pm' -print0 | xargs -0 perl -i -pe "s{\\Q$RPM_BUILD_ROOT}"'{}g'
###
### should these go to a perl-Prima-devel ?
find $RPM_BUILD_ROOT/%{perl_vendorarch} -name \*.h | xargs -t rm
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes Copying examples LICENSE README.md

%changelog
* Sun Jun 12 2016 coolo@suse.com
- updated to 1.47
  see /usr/share/doc/packages/perl-Prima/Changes
  1.47 2016-06-03
  - Add OpenMP support for image scaling and conversion
  - Add custom image scaling algorithms
  - Support JPEG mirror/rotation tags
  - Implement image loading progress display for directions other than top-down (for jpeg and bmp)
* Mon Mar 21 2016 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-Prima/Changes
  1.46 2016-03-16
  - Use pkg_config, when available
  - Require perl version 5.10
  - Add prelighting and gradients to widgets
  1.45 2015-11-05
  - Add Image .clone,.bar,.mirror,.rotate
  - Support bidirectional texts with Text::Bidi
* Sun Sep 20 2015 coolo@suse.com
- updated to 1.44
  see /usr/share/doc/packages/perl-Prima/Changes
  1.44 2015-08-04
  - Rewrite rubberband
  - Work on portable perls
  - Better support of graphic libs where several versions are available
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.43
  see /usr/share/doc/packages/perl-Prima/Changes
  1.43 2015-04-10
  - Rewrite font test and polish rough ends in xft font handling
  - Copy images to clipboard so that GTK recognizes them
  1.42 2015-03-11
  - Tests became TAP compliant and using Prima::Test
  - Jpeg exif orientation support added
  - Scrollbar overriding properties added for scroller widgets
- remove heavily outdated docs and VB-decent.diff
* Thu Jan 29 2015 dimstar@opensuse.org
- Update to version 1.41:
  + Add ImageViewer.autoZoom.
  + Fixes to Notebook  .
- Changes from version 1.40:
  + Remove Win9X support.
  + Cygwin default build is for X11.
  + Compile with giflib 5.1.
  + Add Drawable::Subcanvas.
  + Add ImageViewer.stretch.
  + PS font and eps fixes.
  + win32.gp cliprect fix.
- Changes from version 1.39:
  + Prepare for perl 5.20.
- Changes from version 1.38:
  + X11: add multimonitor support.
  + special char @ means auto-toggle in menu items.
* Thu Sep 12 2013 pgajdos@suse.com
- updated to 1.37
  Support libgif5. Podview fixes.
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.36
  Remove OS/2 support. Add binary compatibility checks.
  Fixes in unicode, files, documentation, installed POD paths.
* Thu Jul 19 2012 coolo@suse.com
- the license is actually BSD-2-Clause, as confirmed by the author,
  next version will have it fixed in the documentation (bnc#688800)
  (https://github.com/dk/Prima/commit/43a3fb04d9915f7f3c3cd71feb5ff247eccd04df)
* Sat Jun  2 2012 frank.lichtenheld@sophos.com
- Update to 1.34
  * 1.34: Unicode fixes, ready for 5.16
  * 1.33: Image codecs: remove prigraph, add XBM, and enhance TIFF support
  Add RubberBand.pm
- Clean up spec file, removing cruft
- Run X11 based tests with Xvfb
* Sat Nov 19 2011 coolo@suse.com
- update to 1.32
    Support image/mime clipboard formats under GTK.
    Better libiconv support.
* Wed May 18 2011 coolo@opensuse.org
- updated to 1.30
  * builds with 5.14
* Fri Apr  1 2011 coolo@novell.com
- update to 1.29
  Support for 16-bit BMP files. Fixes for modern Xorg, macos,
  and strawberry.
  Optionally support truncated image files.
  Fixes in documentation, Sliders, and key event handling.
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Tue Feb 16 2010 coolo@novell.com
- update to 1.28 (very little changelog details):
  * Support JPEG comments and metadata. Save multiframe images.
  * Abandond prigraph, adopt libjpeg/libpng/etc cohort instead.
    Develop gif animation features.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Nov 28 2008 ro@suse.de
- rename GenericEvent (X.h global namespace pollution)
* Tue Apr  8 2008 jw@suse.de
- update to Prima-1.24. The upstream HISTORY file only says this:
  1.24  Better support for mingw and cygwin. New features in VB.
  1.23  Images can load and save to streams. Image loading process can be watched.
  1.22  Use GTK file dialogs if compiled with GTK2. Better use of mouse wheel for
    Calendar, ColorDialog, ComboBox, Notebooks, Scrollbar, and Sliders widgets.
- Added a patch from Dmitry to survive all self-tests on x86_64
* Mon Aug  6 2007 jw@suse.de
- update tp Prima-1.22
  Use GTK file dialogs if compiled with GTK2. Better use of mouse wheel for
  Calendar, ColorDialog, ComboBox, Notebooks, Scrollbar, and Sliders widgets.
* Fri Jun  1 2007 jw@suse.de
- make rpmlint happy.
  No devel package with C-headers for a perl package today.
* Fri Nov 17 2006 jw@suse.de
- update to Prima-1.21
  - no new features. Plain bugfix release.
* Wed Jul 26 2006 jw@suse.de
- happy-gcc.diff added, to fix uninitialized variables in code
  generated by gencls.pl
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 jw@suse.de
- Update to Prima-1.20
* Wed Oct 19 2005 jw@suse.de
- Update to Prima-1.19
  Add Lists::vertical. Implement scrollable groups and notebooks.
  Make file and font dialogs resizeable.
* Tue Apr 26 2005 jw@suse.de
- okay sweety-6 did not like it.
  more Archs have lib64, thanks Marcus.
* Tue Apr 26 2005 jw@suse.de
- fixed warning: File listed twice
- added /usr/X11R6/lib64 for x86_64
- moved man pages out of perl_vendorarch
* Mon Apr 25 2005 jw@suse.de
- initial version: Prima-1.18
